@@ -703,11 +703,11 @@ static GtkWidget *
 wrap_in_frame (const gchar *label,
                GtkWidget   *child)
 {
-	GtkWidget *frame, *alignment, *label_widget;
+	GtkWidget *frame, *label_widget;
 	gchar *bold_text;
 
 	label_widget = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (label_widget), 0.0, 0.5);
+	gtk_widget_set_halign (label_widget, GTK_ALIGN_START);
 	gtk_widget_show (label_widget);
 
 	bold_text = g_markup_printf_escaped ("<b>%s</b>", label);
@@ -716,16 +716,11 @@ wrap_in_frame (const gchar *label,
 
 	frame = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	gtk_box_pack_start (GTK_BOX (frame), label_widget, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (frame), child, FALSE, FALSE, 0);
 
-	alignment = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment),
-				   0, 0, 12, 0);
-	gtk_box_pack_start (GTK_BOX (frame), alignment, FALSE, FALSE, 0);
-
-	gtk_container_add (GTK_CONTAINER (alignment), child);
+	gtk_widget_set_margin_start (child, 12);
 
 	gtk_widget_show (frame);
-	gtk_widget_show (alignment);
 
 	return frame;
 }
@@ -738,7 +733,7 @@ grid_attach_spin_button_with_label (GtkWidget *grid,
 	GtkWidget *label, *spin_button;
 
 	label = gtk_label_new_with_mnemonic (text_label);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_widget_set_halign (label, GTK_ALIGN_START);
 	spin_button = gtk_spin_button_new_with_range (0, 100, 0.01);
 	gtk_spin_button_set_digits (GTK_SPIN_BUTTON (spin_button), 2);
 	gtk_entry_set_width_chars (GTK_ENTRY (spin_button), 6);
@@ -945,7 +940,7 @@ eog_print_image_setup_init (EogPrintImageSetup *setup)
 							   2, 1);
 
 	label = gtk_label_new_with_mnemonic (_("C_enter:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_widget_set_halign (label, GTK_ALIGN_START);
 
 	combobox = gtk_combo_box_text_new ();
 	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (combobox),
@@ -991,7 +986,7 @@ eog_print_image_setup_init (EogPrintImageSetup *setup)
 	priv->scaling = hscale;
 
 	label = gtk_label_new_with_mnemonic (_("_Unit:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_widget_set_halign (label, GTK_ALIGN_START);
 
 	combobox = gtk_combo_box_text_new ();
 	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (combobox), UNIT_MM,
