@@ -534,6 +534,8 @@ eog_thumbnail_init (void)
 	}
 
 	if (frame == NULL) {
-		frame = gdk_pixbuf_new_from_file (EOG_DATA_DIR "/pixmaps/thumbnail-frame.png", NULL);
+		frame = gdk_pixbuf_new_from_resource (
+				"/org/gnome/eog/ui/pixmaps/thumbnail-frame.png",
+				NULL);
 	}
 }
